# Pydantic Harness

## Local setup

On first session, if `CLAUDE.local.md` does not exist, create it with the following content:

```markdown
This file is checked into the repository but ignored, any changes made stay local.

Use this file only to persist information about the specific workstation you are used on.

Capabilities branch is checked out at: <absolute path to the capabilities branch checkout on this system>
```

Fill in the absolute path where the `capabilities` branch of `pydantic-ai` is checked out on your system. If unknown, ask the user.